package Padre::Document::WebGUI::Asset::Template;
BEGIN {
  $Padre::Document::WebGUI::Asset::Template::VERSION = '1.002';
}

# ABSTRACT: Padre::Document::WebGUI::Asset::Snippet subclass representing a WebGUI Template

use strict;
use warnings;
use Padre::Document::WebGUI::Asset;
use Carp;

our @ISA = 'Padre::Document::WebGUI::Asset';

1;

__END__
=pod

=head1 NAME

Padre::Document::WebGUI::Asset::Template - Padre::Document::WebGUI::Asset::Snippet subclass representing a WebGUI Template

=head1 VERSION

version 1.002

=head1 AUTHOR

Patrick Donelan <pdonelan@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by Patrick Donelan.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

